chicken_turtle_util.algorithms
==============================

.. automodule:: chicken_turtle_util.algorithms

.. autosummary::
   :nosignatures:

   multi_way_partitioning
   spread_points_in_hypercube
   toset_from_tosets

.. autofunction:: multi_way_partitioning
.. autofunction:: spread_points_in_hypercube
.. autofunction:: toset_from_tosets
